# remirepo spec file for php-doctrine-lexer, from:
#
# Fedora spec file for php-doctrine-lexer
#
# Copyright (c) 2013-2022 Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#
# Github
%global github_owner     doctrine
%global github_name      lexer
%global github_version   2.0.0
%global github_commit    3cf140b81e55d5d640f73367d829db7e3023ef69
%global github_short     %(c=%{github_commit}; echo ${c:0:7})
%global major            2
# Namespace
%global ns_vendor        Doctrine
%global ns_project       Common
%global ns_subproj       Lexer
# Packagist
%global composer_vendor  doctrine
%global composer_project lexer

# "php": "^7.1 || ^8.0"
%global php_min_ver      7.1

%{!?phpdir:  %global phpdir  %{_datadir}/php}
%global with_tests       0%{!?_without_tests:1}

Name:          php-%{composer_vendor}-%{composer_project}%{major}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Base library for a lexer that can be used in top-down, recursive descent parsers

License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}
# git snapshot with tests
Source0:       %{name}-%{github_version}-%{github_short}.tgz
Source1:       makesrc.sh

BuildArch:     noarch
BuildRequires: php-fedora-autoloader-devel
%if %{with_tests}
# remirepo:1
BuildRequires: php(language) >= %{php_min_ver}
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires:(php-composer(doctrine/deprecations)  >= 1.0   with php-composer(doctrine/deprecations)  < 2)
# remirepo:2
%else
BuildRequires: php-doctrine-deprecations            >= 1.0
%endif
BuildRequires: php-pcre
BuildRequires: php-reflection
BuildRequires: phpunit9
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:     (php-composer(doctrine/deprecations)  >= 1.0   with php-composer(doctrine/deprecations)  < 2)
# remirepo:2
%else
Requires:      php-doctrine-deprecations            >= 1.0
%endif
# phpcompatinfo (computed from version 1.1.0)
Requires:      php-pcre
Requires:      php-reflection
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
Base library for a lexer that can be used in top-down, recursive descent
parsers.

This lexer is used in Doctrine Annotations and in Doctrine ORM (DQL).

This package provides %{composer_vendor}/%{composer_project} version %{major}.

Autoloader: %{phpdir}/%{ns_vendor}/%{ns_project}/%{ns_subproj}/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Generate a simple autoloader
%{_bindir}/phpab \
    --output src/autoload.php \
    --template fedora \
    src

cat << 'EOF' | tee -a src/autoload.php

// Dependencies
\Fedora\Autoloader\Dependencies::required([
    '%{_datadir}/php/%{ns_vendor}/Deprecations/autoload.php',
]);
EOF


%install
mkdir -p   %{buildroot}%{phpdir}/%{ns_vendor}/%{ns_project}
cp -rp src %{buildroot}%{phpdir}/%{ns_vendor}/%{ns_project}/%{ns_subproj}%{major}


%check
%if %{with_tests}
: Generate autoloader
mkdir vendor
%{_bindir}/phpab \
    --output vendor/autoload.php \
    --template fedora \
    tests

cat << 'EOF' | tee -a vendor/autoload.php
require "%{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}/%{ns_subproj}%{major}/autoload.php";
EOF

# we don't want PHPStan (which pull nette framework)

: Run test suite
ret=0
for cmd in php php80 php81 php82; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit9 \
        --bootstrap vendor/autoload.php \
        --verbose || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%dir %{_datadir}/php/%{ns_vendor}/%{ns_project}
     %{_datadir}/php/%{ns_vendor}/%{ns_project}/%{ns_subproj}%{major}


%changelog
* Tue Dec 13 2022 Remi Collet <remi@remirepo.net> - 2.0.0-1
- update to 2.0.0
- rename to php-doctrine-lexer2
- install in /usr/share/php/Doctrine/Common/Lexer2

* Mon Feb 28 2022 Remi Collet <remi@remirepo.net> - 1.2.3-1
- update to 1.2.3

* Wed Jan 12 2022 Remi Collet <remi@remirepo.net> - 1.2.2-1
- update to 1.2.2
- switch to phpunit9

* Tue May 26 2020 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1 (no change)

* Wed Nov 13 2019 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0

* Thu Aug  1 2019 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0
- raise dependency on PHP 7.2
- sources from git snapshot
- run upstream test suite during build
- use classmap autoloader

* Tue Jun 11 2019 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Sat May 13 2017 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-8
- Switch autoloader to php-composer(fedora/autoloader)

* Sat Jun 27 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-5
- Updated autoloader with trailing separator

* Wed Jun 24 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-4
- Added autoloader dependency

* Tue Jun 23 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-3
- Added autoloader

* Mon Jan 05 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-1
- Updated to 1.0.1 (same commit but tagged version instead of snapshot; BZ #1178808)
- %%license usage

* Sun Dec 07 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0-5.20140909git83893c5
- Updated to latest snapshot (required for php-egulias-email-validator 1.2.6)

* Fri Jun 20 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0-4.20131220gitf12a5f7
- Added php-composer(%%{composer_vendor}/%%{composer_project}) virtual provide

* Sat Jan 11 2014 Remi Collet <rpms@famillecollet.com> 1.0-2.20131220gitf12a5f7
- backport for remi repo

* Mon Jan 06 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.0-2.20131220gitf12a5f7
- Conditional %%{?dist}

* Mon Dec 23 2013 Shawn Iwinski <shawn.iwinski@gmail.com> 1.0-1.20131220gitf12a5f7
- Initial package
